==> haskell-text-metrics-0.3.0-5-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-text-metrics.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: text-metrics
version: 0.3.0
id: text-metrics-0.3.0-EFYtxF2maUbHCce05tlYic
key: text-metrics-0.3.0-EFYtxF2maUbHCce05tlYic
license: BSD3
maintainer: Mark Karpov <markkarpov92@gmail.com>
homepage: https://github.com/mrkkrp/text-metrics
synopsis: Calculate various string metrics efficiently
description:
    Calculate various string metrics efficiently.
category: Text, Algorithms
author: Mark Karpov <markkarpov92@gmail.com>
exposed: True
indefinite: False
exposed-modules:
    Data.Text.Metrics
abi: 41cccc70c50137a96bd155fd32285bce
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/text-metrics-0.3.0
library-dirs: /usr/lib/ghc-8.2.2/site-local/text-metrics-0.3.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/text-metrics-0.3.0
hs-libraries: HStext-metrics-0.3.0-EFYtxF2maUbHCce05tlYic
depends:
    base-4.10.1.0 containers-0.5.10.2
    text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj
    vector-0.12.0.1-JlawpRjIcMJIYPJVsWriIA
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj=b7726d921cac66adc5c8f9f66f5b25f0
             vector-0.12.0.1-JlawpRjIcMJIYPJVsWriIA=137c9db50bf637e10c6e6dd9e685ce59
haddock-interfaces: /usr/share/doc/haskell-text-metrics/html/text-metrics.haddock
haddock-html: /usr/share/doc/haskell-text-metrics/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-text-metrics-0.3.0-6-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-text-metrics.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: text-metrics
version: 0.3.0
id: text-metrics-0.3.0-CodlgmXIjVYBIo6lqz2vli
key: text-metrics-0.3.0-CodlgmXIjVYBIo6lqz2vli
license: BSD3
maintainer: Mark Karpov <markkarpov92@gmail.com>
homepage: https://github.com/mrkkrp/text-metrics
synopsis: Calculate various string metrics efficiently
description:
    Calculate various string metrics efficiently.
category: Text, Algorithms
author: Mark Karpov <markkarpov92@gmail.com>
exposed: True
indefinite: False
exposed-modules:
    Data.Text.Metrics
abi: f5a5c29377c3b6a723ac422d22f3ea44
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/text-metrics-0.3.0
library-dirs: /usr/lib/ghc-8.2.2/site-local/text-metrics-0.3.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/text-metrics-0.3.0
hs-libraries: HStext-metrics-0.3.0-CodlgmXIjVYBIo6lqz2vli
depends:
    base-4.10.1.0 containers-0.5.10.2
    text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz
    vector-0.12.0.1-JlawpRjIcMJIYPJVsWriIA
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz=29872508833c96394f0471371217bab0
             vector-0.12.0.1-JlawpRjIcMJIYPJVsWriIA=137c9db50bf637e10c6e6dd9e685ce59
haddock-interfaces: /usr/share/doc/haskell-text-metrics/html/text-metrics.haddock
haddock-html: /usr/share/doc/haskell-text-metrics/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
